==> gdb-8.2.50.20190227.tar.xz: gdb-8.2.50.20190227/bfd/cpu-microblaze.c <==
/* BFD Xilinx MicroBlaze architecture definition

   Copyright (C) 2009-2019 Free Software Foundation, Inc.

   This file is part of BFD, the Binary File Descriptor library.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

#include "sysdep.h"
#include "bfd.h"
#include "libbfd.h"

const bfd_arch_info_type bfd_microblaze_arch =
{
  32,				/* 32 bits in a word.  */
  32,				/* 32 bits in an address.  */
  8,				/* 8 bits in a byte.  */
  bfd_arch_microblaze,		/* Architecture.  */
  0,				/* Machine number - 0 for now.  */
  "microblaze",			/* Architecture name.  */
  "MicroBlaze",			/* Printable name.  */
  3,				/* Section align power.  */
  TRUE,				/* Is this the default architecture ?  */
  bfd_default_compatible,	/* Architecture comparison function.  */
  bfd_default_scan,		/* String to architecture conversion.  */
  bfd_arch_default_fill,	/* Default fill.  */
  NULL				/* Next in list.  */
};

==> gdb_9.1.orig.tar.xz: gdb-9.1/bfd/cpu-microblaze.c <==
/* BFD Xilinx MicroBlaze architecture definition

   Copyright (C) 2009-2019 Free Software Foundation, Inc.

   This file is part of BFD, the Binary File Descriptor library.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

#include "sysdep.h"
#include "bfd.h"
#include "libbfd.h"

const bfd_arch_info_type bfd_microblaze_arch =
{
  32,				/* Bits in a word.  */
  32,				/* Bits in an address.  */
  8,				/* Bits in a byte.  */
  bfd_arch_microblaze,		/* Architecture number.  */
  0,				/* Machine number - 0 for now.  */
  "microblaze",			/* Architecture name.  */
  "MicroBlaze",			/* Printable name.  */
  3,				/* Section align power.  */
  TRUE,				/* Is this the default architecture ?  */
  bfd_default_compatible,	/* Architecture comparison function.  */
  bfd_default_scan,		/* String to architecture conversion.  */
  bfd_arch_default_fill,	/* Default fill.  */
  NULL,				/* Next in list.  */
  0 /* Maximum offset of a reloc from the start of an insn.  */
};
